API Documentation
=================

Welcome to Daft API Documentation. For Daft User Guide, head to `User Guide <../index.html>`_.

.. toctree::
   :hidden:

   creation
   dataframe
   sql
   expressions
   schema
   datatype
   groupby
   udf
   series
   configs
   misc
